Conway's game of life
=====================

Conway's Game of Life implemention with pygame

Screenshots
............

.. image:: screenshots/1.png 


.. image:: screenshots/2.png 

Installation
.............

Install with pip::

  pip install LifeGame

Install from source::

  python3 setup.py install


Running
........

Run via launch script installed with pip package::
  
  GameofLife

Run as a Python module::

  python -m GameofLife
    

Using inside of code
.....................

To import the class in your own code::

  from LifeGame import LifeGame
  LifeGme().run()

Controls
.........

- q --> quit
- s --> pause 
- r--> randomize

Links
......

- https://github.com/Oscarozo/LifeGame.git
- https://pypi.org/project/LifeGame/ 

Contact
........

Oscar Ozorio <osvaldo15963@fpuna.edu.py>




